/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.crop.clm;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.CropProvider;
import org.openide.util.lookup.ServiceProvider;

/**
 * A CropProvider provides agrosense with agrosense crops.
 * This one provides AgroSense Crops retrieved by the CLM webservice (ClmUpdater)
 * 
 * @author Gerben Feenstra
 */
@ServiceProvider(service = CropProvider.class)
public class ClmCropProvider implements CropProvider {

    List<CropDefinition> crops = new ArrayList<>();
    private ClmUpdater clmUpdater;
    private long lastUpdated; // Last updated time in ms since epoch
    
    public ClmCropProvider(){
        clmUpdater = new ClmUpdater(this);
        clmUpdater.init();
        this.lastUpdated = clmUpdater.getStoredLastUpdated();
    }

    @Override
    public String getId() {
        return ClmCropProvider.class.toString();
    }

    @Override
    public long getLastUpdated() {
        return lastUpdated;
    }

    @Override
    public List<CropDefinition> getCrops() {
        return crops;
    }

    /**
     * Will be set by the ClmUpdater.
     * Will set a new lastUpdated to the current datetime
     * @param crops 
     */
    void setCrops(List<CropDefinition> crops){        
        this.crops = crops;  
        this.lastUpdated = new Date().getTime();
    }
}
